<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Форумы и комментарии в SPIP',
	'forum_slogan' => 'Управление форумами и комментариями',
];
